@@ -60,7 +60,12 @@ typedef struct
 	
 	void *x11info;
 	
-	unsigned int expansion[16];
+	int framecount;			// hold number of frames :)
+	
+	liqimage *rotation_native_surface;		// buffer to hold the surface that is not rotated 
+	int rotation_angle;						// if set to != 0 then the ->surface is actually a backbuffer
+	
+	unsigned int expansion[13];
 	
 } liqcanvas;
 
@@ -97,7 +102,7 @@ typedef union
 {
 	struct							// evtype 0,3,4
 	{
-		unsigned int type;
+		int type;
 		unsigned long ticks;
 		unsigned int state;
 	};
@@ -172,23 +177,8 @@ float         liqcanvas_getscalew();
 float         liqcanvas_getscaleh();
 
 
-
-
-
-
-
-
-
-
-
-
-
-
-
-
 #ifdef __cplusplus
 }
 #endif
 
-
 #endif
