@@ -17,7 +17,9 @@
 #include "liqcell.h"
 #include "liqcell_prop.h"
 
-
+#ifdef __cplusplus
+extern "C" {
+#endif
 
 
 liqcell * liqcell_parse_filename(char *filename)
@@ -39,6 +41,9 @@ liqcell * liqcell_parse_filename(char *filename)
 			// create a cell indicating the folder
 
 			self=liqcell_quickcreatenameclass(filename,"dir");
+            liqcell_propseti(self,"filesize", statbuf.st_size);
+            liqcell_propseti(self,"filecount",1);
+			//liqcell_propsets(self,"filestamp",statbuf.st_datestamp);
 
 			// now, recurse :)
 
@@ -62,8 +67,21 @@ liqcell * liqcell_parse_filename(char *filename)
 					
 					// make sure we account for the size :)
 					liqcell_propseti(self,"filesize"  , liqcell_propgeti(self,"filesize",0)  + liqcell_propgeti(c,"filesize", 0) );
-					liqcell_propseti(self,"filecount" , liqcell_propgeti(self,"filecount",0) + liqcell_propgeti(c,"filecount",0) );
+					liqcell_propseti(self,"filecount" , liqcell_propgeti(self,"filecount",0) + liqcell_propgeti(c,"filecount",1) );
+
+					// its a folder.. it should have a range of datestamps within
+					// we should do same for others, will add later					
+					//if( strcmp( liqcell_propgets(self,"filedatemin",""), liqcell_propgets(c,"filedate","") ) < 0)
+					//{
+					//	liqcell_propsets(self,"filedatemin", liqcell_propgets(c,"filedate","") );
+					//}
+					//if( strcmp( liqcell_propgets(self,"filedatemax",""), liqcell_propgets(c,"filedate","") ) > 0)
+					//{
+					//	liqcell_propsets(self,"filedatemax", liqcell_propgets(c,"filedate","") );
+					//}
 					
+					//liqcell_propsets(self,"filedatemin","statbuf.st_datestamp");
+					//liqcell_propsets(self,"filedatemax","statbuf.st_datestamp");
 					
 					
 					
@@ -87,7 +105,7 @@ liqcell * liqcell_parse_filename(char *filename)
 			
 			
 			
-			char *ext=liqapp_filename_walktoextension(filename);
+			const char *ext=liqapp_filename_walktoextension(filename);
 			if(!ext || !*ext)
 			{
 				// nothing to see here..
@@ -173,6 +191,7 @@ liqcell * liqcell_parse_filename(char *filename)
             {
                 liqcell_propseti(self,"filesize", statbuf.st_size);
                 liqcell_propseti(self,"filecount",1);
+				//liqcell_propsets(self,"filedate",statbuf.st_datestamp);
             }
 			
 			
@@ -182,3 +201,7 @@ liqcell * liqcell_parse_filename(char *filename)
 	return self;
 }
 
+#ifdef __cplusplus
+}
+#endif
+
