@@ -332,11 +332,9 @@ FT_Error    fterr;
 
 	//liqapp_log("TTF Font opening face %s, %i:",name,size);
 	char *fn = self->font->filename;
-	// try a few various fonts to try and ensure nice visuals
 	
-	if(!liqapp_fileexists(fn)) fn="/usr/share/fonts/nokia/Nokia Pure/NokiaPureMg.ttf";
-	if(!liqapp_fileexists(fn)) fn="/usr/share/fonts/nokia/nosnb.ttf";
 	if(!liqapp_fileexists(fn)) fn="/usr/share/fonts/droid/DroidSans.ttf";
+	if(!liqapp_fileexists(fn)) fn="/usr/share/fonts/nokia/nosnb.ttf";
 
     fterr = FT_New_Face( ftlib, fn, 0, (FT_Face*)&self->ftface );
 
