@@ -160,7 +160,7 @@ liqimage *liqimage_cache_getfile(const char *filename,int maxw,int maxh,int allo
 	char cachekey[256];
 	int f;
 	snprintf(cachekey,256,"image:%s,%i,%i,%i",filename,maxw,maxh,allowalpha);
-	//liqapp_log( "image cache seeking %s", cachekey );
+	liqapp_log( "image cache seeking %s", cachekey );
 	if(cacheused>=cachemax)
 	{
 		//liqapp_log( "image cache cleaning %s", cachekey );
@@ -179,7 +179,7 @@ liqimage *liqimage_cache_getfile(const char *filename,int maxw,int maxh,int allo
 		if(strcmp(cachestack[f].key,cachekey)==0)
 		{
 			// no differences..
-			//liqapp_log( "image cache matched %s %i", cachekey ,cachestack[f].data->usagecount);
+			liqapp_log( "image cache matched %s %i", cachekey ,cachestack[f].data->usagecount);
 			self = cachestack[f].data;
 			//self->usagecount++;
 			liqimage_hold(self);
@@ -214,7 +214,7 @@ liqimage *liqimage_cache_getfile(const char *filename,int maxw,int maxh,int allo
 	
 	//self->usagecount=1;
 
-	//liqapp_log( "TTF cache inserting %s", cachekey );
+	liqapp_log( "image cache inserting %s", cachekey );
 	
 	
 	// todo:  fix the bug here when threaded loading occuring
@@ -229,7 +229,7 @@ liqimage *liqimage_cache_getfile(const char *filename,int maxw,int maxh,int allo
 	
 	pthread_mutex_unlock(&cachestack_lock);
 
-	////liqapp_log( "TTF cache completed %s", cachekey );
+	liqapp_log( "image cache completed %s", cachekey );
 	return self;
 }
 
@@ -358,7 +358,7 @@ liqimage *liqimage_newfromfile(const char *filename,int maxw,int maxh,int allowa
 	
 	
 	
-	
+/*	
 	if(
 		strcasecmp(ext,"jpg")==0  ||
 		strcasecmp(ext,"jpeg")==0
@@ -388,7 +388,7 @@ liqimage *liqimage_newfromfile(const char *filename,int maxw,int maxh,int allowa
 		return self;
 	}
 	
-	
+*/	
 
 	
 	// try and sniff?
@@ -400,6 +400,8 @@ liqimage *liqimage_newfromfile(const char *filename,int maxw,int maxh,int allowa
 		memset(buffer,0,sizeof(buffer));
 		
 		int result = fread(buffer,1,sizeof(buffer),fp);
+
+		buffer[11] = 0;
 		
 		fclose(fp);
 		if (result != sizeof(buffer))
@@ -407,7 +409,7 @@ liqimage *liqimage_newfromfile(const char *filename,int maxw,int maxh,int allowa
 			liqapp_log("Reading error",stderr);
 		}
 		
-		if(strncmp(&buffer[6],"JFIF",4)==0)
+		if(strncmp(&buffer[6],"JFIF",4)==0 || strncmp(&buffer[6],"Exif",4)==0)
 		{
 			// its a jpeg
 			if(liqimage_pageloadjpeg(self,filename,maxw,maxh)!=0)
@@ -429,7 +431,12 @@ liqimage *liqimage_newfromfile(const char *filename,int maxw,int maxh,int allowa
 			}
 			return self;
 		}		
-
+	
+	
+		liqapp_log("liqimage_newfromfile invalid filedata '%s' : '%s'",filename, buffer);
+		liqimage_free(self);
+		return NULL;
+	
 	
 	}
 	
