@@ -8,6 +8,7 @@
 #include "liqcell_prop.h"
 #include "liqcell_easyrun.h"
 #include "liqcell_easypaint.h"
+#include "liqtag.h"
 
 
 // 20100628_0325 lcuk : removing the cover so that liqpostcard works - liqsketch will end up in its own project soon
@@ -26,14 +27,17 @@
 //#####################################################################
 
 
-#include <curl/curl.h>
-
 
 #ifdef __cplusplus
 extern "C" {
 #endif
 
 
+/*
+
+
+#include <curl/curl.h>
+
 
 struct curl_memorybuffer
 {
@@ -160,7 +164,7 @@ int post_to_liqbase_net(const char *filename, const char *datakey,int replyid)
 }
 
  
-
+*/
 
 
 
@@ -230,9 +234,18 @@ int post_to_liqbase_net(const char *filename, const char *datakey,int replyid)
 		liqsketch_filesave(liqcell_getsketch(self), filenamebuffer );
 
 
+		char *monitortag = liqcell_propgets(self,"monitortag",NULL);
+		if(monitortag && *monitortag)
+		{
+			//
+			liqtag_quicksaveas( monitortag, filenamebuffer );
+		}
+
+
 		liqcell_propsets(self,"sketchfilenamelast",filenamebuffer);
 		
-		post_to_liqbase_net(filenamebuffer,key,0);
+		// removing, the sync module will do this better.
+		//post_to_liqbase_net(filenamebuffer,key,0);
 		
 		liqcell_settag(self,0);
 		
@@ -244,6 +257,22 @@ int post_to_liqbase_net(const char *filename, const char *datakey,int replyid)
 
 	static int liqsketchedit_shown(liqcell *self, liqcelleventargs *args, void *context)
 	{
+		char *monitortag = liqcell_propgets(self,"monitortag",NULL);
+		if(monitortag && *monitortag)
+		{
+
+			//############################# title:label
+			liqcell *title = liqcell_quickcreatevis("title", "label", 0,0, self->w, 56);
+			liqcell_setfont(	title, liqfont_cache_getttf("/usr/share/fonts/nokia/nosnb.ttf", (40), 0) );
+			liqcell_setcaption_printf(title, "Draw a '%s'",monitortag );
+			liqcell_propsets(  title, "textcolor", "rgb(255,255,255)" );
+			liqcell_propsets(  title, "backcolor", "xrgb(0,0,60)" );
+			liqcell_propseti(  title, "textalign", 0 );
+			liqcell_child_append(  self, title);
+		}
+
+
+	
         // shown for the first time :)
         liqcell *cover = liqcell_child_lookup(self,"cover");
         if(liqcell_getlinkparent( self) == NULL )
@@ -344,56 +373,26 @@ int post_to_liqbase_net(const char *filename, const char *datakey,int replyid)
 		return 1;
 	}
 
-
-
-	static int liqsketchedit_clear_click(liqcell *self, liqcellclickeventargs *args, void *context)
-	{
-		liqcell *editor = liqcell_getlinkparent(self);
-
-		liqsketch *sketch = liqcell_getsketch(editor);
-		if(!sketch)
-		{
-			return 0;
-		}
-
-		liqsketch_clear(sketch);
-
-        
-		char *fn=liqcell_propgets(editor,"sketcheditfilename",NULL);        // fixed name bug would not reload, thanks javispedro
-		if(fn)
-		{
-			// 20090421_233231 lcuk : save it now with the special assigned name
-			liqsketch_fileload(sketch, fn );
-
-			return 1;
-		}
-		
-		liqcell_handlerrun(editor,"cleared",NULL);
-		
-		liqcell_settag(editor,0);
-
-		return 1;
-	}
-
 	static int liqsketchedit_del_click(liqcell *self, liqcellclickeventargs *args, void *context)
 	{
-		
+		liqapp_log("sketch del start");
 		liqcell *editor = liqcell_getlinkparent(self);
 
 		liqsketch *sketch = liqcell_getsketch(editor);
 		if(!sketch)
 		{
-			
+			liqapp_log("sketch del no sketch");
 			return 0;
 		}
 		
-		
+		liqapp_log("sketch del clearing");		
 
 		liqsketch_clear(sketch);
 
 		char *fn=liqcell_propgets(editor,"sketcheditfilename",NULL);      // fixed name bug would not delete, thanks javispedro
 		if(fn)
 		{
+			liqapp_log("sketch del special sketch '%s'",fn);
 			// 20090422_000423 lcuk : delete the actual file now
 			if(liqapp_fileexists(fn))
 			{
@@ -406,36 +405,93 @@ int post_to_liqbase_net(const char *filename, const char *datakey,int replyid)
 				liqapp_log("sketch delete cmd: %s",s);
 			}
 		}
+
+		liqapp_log("sketch del tidying up");
 		
 		liqcell_setsketch(editor,NULL);
 		
 		liqcell_settag(editor, (void*)1);
 
+		liqapp_log("sketch del tidying up, raising cleared event (hmm)");
 
 		liqcell_handlerrun(editor,"cleared",NULL);
+
+		liqapp_log("sketch del completed");
 		
 		return 1;
 	}
 
+	static int liqsketchedit_clear_click(liqcell *self, liqcellclickeventargs *args, void *context)
+	{
+		liqapp_log("clear start");
+		liqcell *editor = liqcell_getlinkparent(self);
+
+		liqsketch *sketch = liqcell_getsketch(editor);
+		if(!sketch)
+		{
+			liqapp_log("clear no sketch");
+			return 0;
+		}
+
+		if(sketch->strokecount==0)
+		{
+			liqapp_log("clear deleting instead");
+			// delete instead
+			liqsketchedit_del_click(self,args,context);
+			return 1;
+		}
+
+		liqapp_log("clear clearing");
+
+		liqsketch_clear(sketch);
+
+        
+		char *fn=liqcell_propgets(editor,"sketcheditfilename",NULL);        // fixed name bug would not reload, thanks javispedro
+		if(fn)
+		{
+			// liqapp_log("clear reloading special sketch: '%s'",fn);
+			// // 20090421_233231 lcuk : save it now with the special assigned name
+			// liqsketch_fileload(sketch, fn );
+			liqapp_log("clear special deleting instead '%s'",fn);
+			// delete instead
+			liqsketchedit_del_click(self,args,context);
+			
+
+			return 1;
+		}
+
+		liqapp_log("clear tidying up, raising cleared event");
+		
+		liqcell_handlerrun(editor,"cleared",NULL);
+		
+		liqcell_settag(editor,0);
+
+		liqapp_log("clear completed");
+
+		return 1;
+	}
+
+
+
 	static int liqsketchedit_save_click(liqcell *self, liqcellclickeventargs *args, void *context)
 	{
 		liqcell *editor = liqcell_getlinkparent(self);
-
+liqapp_log("liqsketchedit_save_click 1");
 		liqsketch *sketch = liqcell_getsketch(editor);
 		if(!sketch)
 		{
 			liqapp_log("liqsketchedit_save_click nothing to save");
 			return 0;
 		}
-
+liqapp_log("liqsketchedit_save_click 2");
 		liqsketchedit_save(editor);
-
+liqapp_log("liqsketchedit_save_click 3");
 		liqsketch_clear(sketch);
-		
+liqapp_log("liqsketchedit_save_click 4");
 		liqcell_handlerrun(editor,"cleared",NULL);
-		
+liqapp_log("liqsketchedit_save_click 5");
 		liqcell_settag(editor,0);
-
+liqapp_log("liqsketchedit_save_click 6");
 
 		return 1;
 	}
@@ -567,17 +623,124 @@ static int liqsketchedit_resize(liqcell *self, liqcelleventargs *args, void *con
 */
 	// rotation patch test
 	liqcell_setrect(cover,  0,  0,            ww*1.0,hh*1.0);
-	liqcell_setrect(undo,  ww*0.0,  hh*0.9,   ww*0.3,hh*0.1);
-	liqcell_setrect(clear, ww*0.3,  hh*0.9,   ww*0.3,hh*0.1);
-	liqcell_setrect(save , ww*0.6,  hh*0.9,   ww*0.3,hh*0.1);
-	liqcell_setrect(del ,  ww*0.9,  hh*0.9,   ww*0.1,hh*0.1);
+	liqcell_setrect(undo,  ww*0.050,  hh*0.9,   ww*0.333-ww*0.05,hh*0.1);
+	liqcell_setrect(clear, ww*0.333,  hh*0.9,   ww*0.333,hh*0.1);
+	liqcell_setrect(save , ww*0.666,  hh*0.9,   ww*0.333,hh*0.1);
+	//liqcell_setrect(del ,  ww*0.9,  hh*0.9,   ww*0.1,hh*0.1);
 	liqcell_setrect(notes ,  ww*0.25,  hh*1,   ww*0.5,hh*0.1);
 		
 	return 0;
 }
 
+	static int liqsketchedit_layout(liqcell *self, liqcelleventargs *args,liqcell *liqsketchedit)
+	{
+
+		// ##################################################
+		liqcell *topself = liqcell_easyrunstack_topself();
+		//if(self == topself)
+		{
+			// ##################################################
+			liqapp_log("sk.paint: this sketcheditor is top of the world");
+			//if(self->w != liqcanvas_getwidth() || self->h != liqcanvas_getheight())
+			{
+				// rescaling
+				liqapp_log("sk.paint: rescale");
+				liqcell_setsize( self, liqcanvas_getwidth(), liqcanvas_getheight() );
+				//liqcell_setdirty(self,1);
+				//return -1;
+			}
+
+			// ##################################################
+			liqapp_log("sk.paint: now see about rescaling the content");
+
+			liqsketch *sk = liqcell_getsketch(self);
+			if(sk)
+			{
+				liqapp_log("sk.paint: we have content sketch");
+
+
+				int cn_orient =  (liqcanvas_getwidth() > liqcanvas_getheight());
+				int sk_orient =  (sk->pixelwidth       > sk->pixelheight);
+
+				liqapp_log("sk.paint: cn wh(%d,%d) :: %d",liqcanvas_getwidth(), liqcanvas_getheight(),  cn_orient);
+				liqapp_log("sk.paint: sk wh(%d,%d) :: %d",sk->pixelwidth, sk->pixelheight,              sk_orient);
+
+
+				if(cn_orient != sk_orient)
+				{
+					liqapp_log("sk.paint: we have orientation difference");
+					int uw = sk->boundingbox.xr - sk->boundingbox.xl;
+					int uh = sk->boundingbox.yb - sk->boundingbox.yt;
+					liqapp_log("sk.paint: u wh(%d,%d)",uw,uh);
+					liqapp_log("sk.paint: does the sketch fit by just adjusting its border?");
+					liqapp_log("sk.paint: size wh(%d,%d)",sk->pixelwidth,sk->pixelheight);
+
+					sk->pixelwidth = liqcanvas_getwidth();
+					sk->pixelheight = liqcanvas_getheight();
+
+
+					//int t = sk->pixelwidth;  sk->pixelwidth = sk->pixelheight; sk->pixelheight = t;
+
+					int first=1;
+					int offx = sk->pixelwidth  * 0.1;
+					int offy = sk->pixelheight * 0.1;
+					int adjx = sk->boundingbox.xl ;
+					int adjy = sk->boundingbox.yt ;
+					float factorx = (float)(sk->pixelwidth * 0.8)  / (float)(sk->boundingbox.xr - sk->boundingbox.xl);
+					float factory = (float)(sk->pixelheight* 0.8) / (float)(sk->boundingbox.yb - sk->boundingbox.yt);
+					if(factorx<factory)
+						factory=factorx;
+					else
+						factorx=factory;
+					if( sk->boundingbox.xr > (sk->pixelwidth * 0.8) || sk->boundingbox.yb > (sk->pixelheight * 0.8) )
+					{
+					
+						// 
+						liqapp_log("sk.paint: bb x(%d,%d),y(%d,%d)", sk->boundingbox.xl,sk->boundingbox.xr,sk->boundingbox.yt,sk->boundingbox.yb );
+						liqapp_log("sk.paint: adjusting : adj(%d,%d) fac(%3.3f,%3.3f)",adjx,adjy,factorx,factory);
+						liqstroke *st = sk->strokefirst;
+						while(st)
+						{
+							//liqapp_log("sk.paint: stroke");
+							liqpoint *p = st->pointfirst;
+							while(p)
+							{
+								//liqapp_log("sk.paint: stroke.point");
+								p->x =offx+ (float)(p->x-adjx) * factorx;
+								p->y =offy+ (float)(p->y-adjy) * factory;
+								p=p->linknext;
+							}
+							st->boundingbox.xl =offx+ (float)(st->boundingbox.xl-adjx) * factorx;
+							st->boundingbox.xr =offx+ (float)(st->boundingbox.xr-adjx) * factorx;
+							st->boundingbox.yt =offy+ (float)(st->boundingbox.yt-adjy) * factory;
+							st->boundingbox.yb =offy+ ((float)st->boundingbox.yb-adjy) * factory;
+							st=st->linknext;
+						}
+						sk->boundingbox.xl =offx+ (float)(sk->boundingbox.xl-adjx) * factorx;
+						sk->boundingbox.xr =offx+ (float)(sk->boundingbox.xr-adjx) * factorx;
+						sk->boundingbox.yt =offy+ (float)(sk->boundingbox.yt-adjy) * factory;
+						sk->boundingbox.yb =offy+ (float)(sk->boundingbox.yb-adjy) * factory;
+					}
+					liqapp_log("sk.paint: done");
+
+					if(cn_orient)
+					{
+					}
+					else
+					{
+					}
+				}
+			}
+		}
+
+
+		return 0;
+	}
+
 	static int liqsketchedit_paint(liqcell *self, liqcellpainteventargs *args,liqcell *liqsketchedit)
 	{
+	
+	
 		liqcell *notes = liqcell_child_lookup(liqsketchedit,"notes");
 		char *cap=liqcell_getcaption(notes);
 		if(cap && *cap)
@@ -635,35 +798,40 @@ liqcell *liqsketchedit_create()
 		liqcell_child_insert( self, b );
 
 		b = liqcell_quickcreatevis("undo","button",  800-180,20,   160,160 );
-		liqcell_setfont(   b, liqfont_cache_getttf("/usr/share/fonts/nokia/nosnb.ttf", (24), 0) );
+		liqcell_setfont(   b, liqfont_cache_getttf("/usr/share/fonts/nokia/nosnb.ttf", (32), 0) );
 		liqcell_handleradd(b,    "click",   (void*)liqsketchedit_undo_click);
 		liqcell_propsets(  b,    "backcolor", "xrgb(100,0,100)" );
+		liqcell_propseti( b, "textaligny", 2 );
 		liqcell_handleradd(b,    "mouse",   (void*)liqsketchedit__cmdnull_mouse);
 		liqcell_child_insert( self, b );
 
 
 		b = liqcell_quickcreatevis("clear","button",  800-180,20,   160,160 );
-		liqcell_setfont(   b, liqfont_cache_getttf("/usr/share/fonts/nokia/nosnb.ttf", (24), 0) );
+		liqcell_setfont(   b, liqfont_cache_getttf("/usr/share/fonts/nokia/nosnb.ttf", (32), 0) );
 		liqcell_handleradd(b,    "click",   (void*)liqsketchedit_clear_click);
 		liqcell_propsets(  b,    "backcolor", "xrgb(0,0,100)" );
+		liqcell_propseti( b, "textaligny", 2 );
 		liqcell_handleradd(b,    "mouse",   (void*)liqsketchedit__cmdnull_mouse);
 		liqcell_child_insert( self, b );
 	
 
 		b = liqcell_quickcreatevis("save","button",  800-180,200,   160,160 );
-		liqcell_setfont(   b, liqfont_cache_getttf("/usr/share/fonts/nokia/nosnb.ttf", (24), 0) );
+		liqcell_setfont(   b, liqfont_cache_getttf("/usr/share/fonts/nokia/nosnb.ttf", (32), 0) );
 		liqcell_handleradd(b,    "click",   (void*)liqsketchedit_save_click);
 		liqcell_propsets(  b,    "backcolor", "xrgb(0,100,0)" );
+		liqcell_propseti( b, "textaligny", 2 );
 		liqcell_handleradd(b,    "mouse",   (void*)liqsketchedit__cmdnull_mouse);
 		liqcell_child_insert( self, b );
 
 
 		b = liqcell_quickcreatevis("del","button",  800-180,200,   160,160 );
-		liqcell_setfont(   b, liqfont_cache_getttf("/usr/share/fonts/nokia/nosnb.ttf", (24), 0) );
+		liqcell_setfont(   b, liqfont_cache_getttf("/usr/share/fonts/nokia/nosnb.ttf", (32), 0) );
 		liqcell_handleradd(b,    "click",   (void*)liqsketchedit_del_click);
 		liqcell_propsets(  b,    "backcolor", "xrgb(100,0,0)" );
+		liqcell_propseti( b, "textaligny", 2 );
 		liqcell_handleradd(b,    "mouse",   (void*)liqsketchedit__cmdnull_mouse);
 		liqcell_child_insert( self, b );
+		liqcell_setvisible(b,0);
 
 
 		b = liqcell_quickcreatevis("notes","textbox",  200,480,   480,80 );
@@ -688,7 +856,9 @@ liqcell *liqsketchedit_create()
 		liqcell_handleradd_withcontext(self,    "mouse",   (void*)liqsketchedit_mouse,   self);
 		liqcell_handleradd_withcontext(self,    "resize",   (void*)liqsketchedit_resize,   self);
 		liqcell_handleradd_withcontext(self,    "paint",   (void*)liqsketchedit_paint,   self);
+		liqcell_handleradd_withcontext(self,    "layout",   (void*)liqsketchedit_layout,   self);
 		
+			
 		
 	}
 	return self;
